==> developer-center-api-1.6.2-20170113.075736-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/RecommendBlacklistDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Date;


public class RecommendBlacklistDto implements Serializable {

	private static final long serialVersionUID = 3746531279549774182L;

	private Long id;
	private Long appId;//应用ID
	/** 注意：在对应的表中没有app_name这个字段,但是页面还是保留显示,需要去app表中动态获取 */
	private String appName;//应用名称
	private Long developId;//开发者ID
	private String email;//开发者账号
	private boolean duibaActivity;//兑吧活动
	private boolean ownActivity;//自有活动
	private boolean goods;//商品(兑换项)
	
	private Date gmtCreate;//创建日期
	private Date gmtModified;//修改日期
	
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getAppName() {
		return appName;
	}
	public void setAppName(String appName) {
		this.appName = appName;
	}
	public Long getDevelopId() {
		return developId;
	}
	public void setDevelopId(Long developId) {
		this.developId = developId;
	}
	public String getEmail() {
		return email;
	}
	public void setEmail(String email) {
		this.email = email;
	}
	public boolean isDuibaActivity() {
		return duibaActivity;
	}
	public void setDuibaActivity(boolean duibaActivity) {
		this.duibaActivity = duibaActivity;
	}
	public boolean isOwnActivity() {
		return ownActivity;
	}
	public void setOwnActivity(boolean ownActivity) {
		this.ownActivity = ownActivity;
	}
	public boolean isGoods() {
		return goods;
	}
	public void setGoods(boolean goods) {
		this.goods = goods;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	
}

==> developer-center-api-3.9.18-sources.jar: cn/com/duiba/developer/center/api/domain/dto/RecommendBlacklistDto.java <==
package cn.com.duiba.developer.center.api.domain.dto;

import java.io.Serializable;
import java.util.Date;


public class RecommendBlacklistDto implements Serializable {

	private static final long serialVersionUID = 3746531279549774182L;
	
	public RecommendBlacklistDto() {
		
	}

	public RecommendBlacklistDto(Long appId, String appName, Long developId,
			String email, boolean duibaActivity, boolean ownActivity,
			boolean goods) {
		super();
		this.appId = appId;
		this.appName = appName;
		this.developId = developId;
		this.email = email;
		this.duibaActivity = duibaActivity;
		this.ownActivity = ownActivity;
		this.goods = goods;
	}

	private Long id;
	private Long appId;//应用ID
	/** 在对应的表中没有app_name这个字段,但是页面还是保留显示,需要去app表中动态获取 */
	private String appName;//应用名称
	private Long developId;//开发者ID
	private String email;//开发者账号
	private boolean duibaActivity;//兑吧活动
	private boolean ownActivity;//自有活动
	private boolean goods;//商品(兑换项)
	
	private Date gmtCreate;//创建日期
	private Date gmtModified;//修改日期
	
	public Long getId() {
		return id;
	}
	public void setId(Long id) {
		this.id = id;
	}
	public Long getAppId() {
		return appId;
	}
	public void setAppId(Long appId) {
		this.appId = appId;
	}
	public String getAppName() {
		return appName;
	}
	public void setAppName(String appName) {
		this.appName = appName;
	}
	public Long getDevelopId() {
		return developId;
	}
	public void setDevelopId(Long developId) {
		this.developId = developId;
	}
	public String getEmail() {
		return email;
	}
	public void setEmail(String email) {
		this.email = email;
	}
	public boolean isDuibaActivity() {
		return duibaActivity;
	}
	public void setDuibaActivity(boolean duibaActivity) {
		this.duibaActivity = duibaActivity;
	}
	public boolean isOwnActivity() {
		return ownActivity;
	}
	public void setOwnActivity(boolean ownActivity) {
		this.ownActivity = ownActivity;
	}
	public boolean isGoods() {
		return goods;
	}
	public void setGoods(boolean goods) {
		this.goods = goods;
	}
	public Date getGmtCreate() {
		return gmtCreate;
	}
	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
	public Date getGmtModified() {
		return gmtModified;
	}
	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
	
}
